/// <reference types="node" />
/// <reference types="node" />
import { IncomingMessage, ServerResponse } from "http";
import { StringDictionary, uint16, uint32 } from "./types";
/**
 * This is a minimal HTTP server class provided for testing
 */
export declare type TSEndPoint = (url: URL, req: IncomingMessage, resp: ServerResponse) => Promise<void>;
export declare type TSEndPoints = {
    [key: string]: TSEndPoint;
};
export declare enum TSLogType {
    Log = "Info",
    Warning = "Warning",
    Error = "Error"
}
export declare type TSServerLogger = (server: TSServer, req: IncomingMessage | undefined, type: TSLogType, messages: string) => Promise<void>;
export interface TSServerOptions {
    host?: string;
    port?: uint16;
    staticFolders?: string[];
    staticContentTypes?: StringDictionary;
    maxCacheSize?: uint32;
    maxCachedFileSize?: uint32;
    logger?: TSServerLogger;
}
export declare class TSServer {
    private static __server;
    private static readonly __logHeaders;
    private _httpServer;
    private _endPoints;
    private _statics;
    private _cache;
    private _blacklisted;
    private _maxBlacklistedFiles;
    private _cachedFileSizeMax;
    private _maxCachedFiles;
    private _maxCacheMemorySize;
    private _cacheMemory;
    private _managedTypes;
    private _logger;
    host: string;
    port: number;
    static start(endPoints: TSEndPoints, opts?: TSServerOptions): Promise<void>;
    static clearCaches(): Promise<void>;
    static stop(): Promise<Error | undefined>;
    static standardTypes(): StringDictionary;
    private constructor();
    private _start;
    getStaticResource(path: string): [Buffer | undefined | null, string];
    private _clearCaches;
    private _stop;
}
